@@ -1,20 +1,7 @@
-#  Copyright (c) 2019 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA Records Ansible is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA Records Ansible is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA Records Ansible. If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
+import collections
 import hashlib
 import json
 import zlib
@@ -81,6 +68,33 @@ class CreatableSlugRelatedField(serializers.SlugRelatedField):
     Used for creating or retrieving labels by name.
     """
 
+    def to_representation(self, obj):
+        return {"id": obj.id, "name": obj.name}
+
+    # Overriding RelatedField.to_representation causes error in Browseable API
+    # https://github.com/encode/django-rest-framework/issues/5141
+    def get_choices(self, cutoff=None):
+        queryset = self.get_queryset()
+        if queryset is None:
+            # Ensure that field.choices returns something sensible
+            # even when accessed with a read-only field.
+            return {}
+
+        if cutoff is not None:
+            queryset = queryset[:cutoff]
+
+        return collections.OrderedDict(
+            [
+                (
+                    # This is the only line that differs
+                    # from the RelatedField's implementation
+                    item.pk,
+                    self.display_value(item),
+                )
+                for item in queryset
+            ]
+        )
+
     def to_internal_value(self, data):
         try:
             return self.get_queryset().get_or_create(**{self.slug_field: data})[0]
