@@ -1,23 +1,11 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from django.db import models
 from django.utils import timezone
 
+from ara.setup import ara_version
+
 
 class Base(models.Model):
     """
@@ -48,7 +36,7 @@ class Duration(Base):
         # Compute duration based on available timestamps
         if self.ended is not None:
             self.duration = self.ended - self.started
-        return super(Duration, self).save(*args, **kwargs)
+        return super().save(*args, **kwargs)
 
 
 class Label(Base):
@@ -98,10 +86,15 @@ class Playbook(Duration):
 
     name = models.CharField(max_length=255, null=True)
     ansible_version = models.CharField(max_length=255)
+    client_version = models.CharField(max_length=255, null=True)
+    python_version = models.CharField(max_length=255, null=True)
+    server_version = models.CharField(max_length=255, default=ara_version)
     status = models.CharField(max_length=25, choices=STATUS, default=UNKNOWN)
-    arguments = models.BinaryField(max_length=(2 ** 32) - 1)
+    arguments = models.BinaryField(max_length=(2**32) - 1)
     path = models.CharField(max_length=255)
     labels = models.ManyToManyField(Label)
+    controller = models.CharField(max_length=255, null=True, default="localhost")
+    user = models.CharField(max_length=255, null=True)
 
     def __str__(self):
         return "<Playbook %s>" % self.id
@@ -118,7 +111,7 @@ class FileContent(Base):
         db_table = "file_contents"
 
     sha1 = models.CharField(max_length=40, unique=True)
-    contents = models.BinaryField(max_length=(2 ** 32) - 1)
+    contents = models.BinaryField(max_length=(2**32) - 1)
 
     def __str__(self):
         return "<FileContent %s:%s>" % (self.id, self.sha1)
@@ -153,7 +146,7 @@ class Record(Base):
         unique_together = ("key", "playbook")
 
     key = models.CharField(max_length=255)
-    value = models.BinaryField(max_length=(2 ** 32) - 1)
+    value = models.BinaryField(max_length=(2**32) - 1)
     type = models.CharField(max_length=255)
     playbook = models.ForeignKey(Playbook, on_delete=models.CASCADE, related_name="records")
 
@@ -192,18 +185,27 @@ class Task(Duration):
     class Meta:
         db_table = "tasks"
 
-    # A task in ARA can be running (in progress) or completed (regardless of success or failure)
-    # Actual task statuses (such as failed, skipped, etc.) are actually in the Results table.
-    UNKNOWN = "unknown"
-    RUNNING = "running"
+    # Possible statuses for a task
+    # A failed task is expected to have at least one failed result
     COMPLETED = "completed"
     EXPIRED = "expired"
-    STATUS = ((UNKNOWN, "unknown"), (RUNNING, "running"), (COMPLETED, "completed"), (EXPIRED, "expired"))
+    FAILED = "failed"
+    RUNNING = "running"
+    UNKNOWN = "unknown"
+
+    STATUS = (
+        (COMPLETED, "completed"),
+        (EXPIRED, "expired"),
+        (FAILED, "failed"),
+        (RUNNING, "running"),
+        (UNKNOWN, "unknown"),
+    )
 
     name = models.TextField(blank=True, null=True)
+    uuid = models.UUIDField(null=True)
     action = models.TextField()
     lineno = models.IntegerField()
-    tags = models.BinaryField(max_length=(2 ** 32) - 1)
+    tags = models.BinaryField(max_length=(2**32) - 1)
     handler = models.BooleanField()
     status = models.CharField(max_length=25, choices=STATUS, default=UNKNOWN)
 
@@ -225,7 +227,7 @@ class Host(Base):
         unique_together = ("name", "playbook")
 
     name = models.CharField(max_length=255)
-    facts = models.BinaryField(max_length=(2 ** 32) - 1)
+    facts = models.BinaryField(max_length=(2**32) - 1)
 
     changed = models.IntegerField(default=0)
     failed = models.IntegerField(default=0)
@@ -239,6 +241,27 @@ class Host(Base):
         return "<Host %s:%s>" % (self.id, self.name)
 
 
+class LatestHost(models.Model):
+    """
+    Latest record of each host based on name, referring to `Host` object id related.
+
+    We can not inherit from Base because we want to use `name` as primary key.
+    """
+
+    class Meta:
+        db_table = "latest_hosts"
+
+    name = models.CharField(max_length=255, primary_key=True)
+    host = models.ForeignKey(Host, on_delete=models.CASCADE)
+
+    # because we can't inherit from Base (see above) we have to define this here additionally
+    created = models.DateTimeField(auto_now_add=True)
+    updated = models.DateTimeField(auto_now=True)
+
+    def __str__(self):
+        return "<LatestHost %s>" % (self.name)
+
+
 class Result(Duration):
     """
     Data about Ansible results.
@@ -271,8 +294,9 @@ class Result(Duration):
     ignore_errors = models.BooleanField(default=False)
 
     # todo use a single Content table
-    content = models.BinaryField(max_length=(2 ** 32) - 1)
+    content = models.BinaryField(max_length=(2**32) - 1)
     host = models.ForeignKey(Host, on_delete=models.CASCADE, related_name="results")
+    delegated_to = models.ManyToManyField(Host)
     task = models.ForeignKey(Task, on_delete=models.CASCADE, related_name="results")
     play = models.ForeignKey(Play, on_delete=models.CASCADE, related_name="results")
     playbook = models.ForeignKey(Playbook, on_delete=models.CASCADE, related_name="results")
