@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from rest_framework import serializers
 
@@ -74,8 +60,7 @@ class FileSha1Serializer(serializers.ModelSerializer):
 
 
 #######
-# Simple serializers provide lightweight representations of objects without
-# nested or large fields.
+# Simple serializers provide lightweight representations of objects suitable for inclusion in other objects
 #######
 
 
@@ -88,106 +73,36 @@ class SimpleLabelSerializer(serializers.ModelSerializer):
 class SimplePlaybookSerializer(ItemCountSerializer):
     class Meta:
         model = models.Playbook
-        exclude = ("arguments", "created", "updated")
+        exclude = ("created", "updated")
 
+    arguments = ara_fields.CompressedObjectField(default=ara_fields.EMPTY_DICT, read_only=True)
     labels = SimpleLabelSerializer(many=True, read_only=True, default=[])
 
 
 class SimplePlaySerializer(ItemCountSerializer):
     class Meta:
         model = models.Play
-        exclude = ("uuid", "created", "updated")
+        exclude = ("playbook", "uuid", "created", "updated")
 
 
 class SimpleTaskSerializer(ItemCountSerializer, TaskPathSerializer):
     class Meta:
         model = models.Task
-        exclude = ("tags", "created", "updated")
+        exclude = ("playbook", "play", "created", "updated")
 
-
-class SimpleResultSerializer(ResultStatusSerializer):
-    class Meta:
-        model = models.Result
-        exclude = ("content", "created", "updated")
+    tags = ara_fields.CompressedObjectField(read_only=True)
 
 
 class SimpleHostSerializer(serializers.ModelSerializer):
     class Meta:
         model = models.Host
-        exclude = ("facts", "created", "updated")
+        exclude = ("playbook", "facts", "created", "updated")
 
 
 class SimpleFileSerializer(FileSha1Serializer):
     class Meta:
         model = models.File
-        exclude = ("content", "created", "updated")
-
-
-class SimpleRecordSerializer(serializers.ModelSerializer):
-    class Meta:
-        model = models.Record
-        exclude = ("value", "created", "updated")
-
-
-#######
-# Nested serializers returns optimized data within the context of another object.
-# For example: when retrieving a playbook, we'll already have the playbook id
-# so it is not necessary to include it in nested objects.
-#######
-
-
-class NestedPlaybookFileSerializer(serializers.ModelSerializer):
-    class Meta:
-        model = models.File
-        exclude = ("content", "created", "updated", "playbook")
-
-
-class NestedPlaybookHostSerializer(serializers.ModelSerializer):
-    class Meta:
-        model = models.Host
-        fields = ("id", "name")
-
-
-class NestedPlaybookResultSerializer(ResultStatusSerializer):
-    class Meta:
-        model = models.Result
-        exclude = ("content", "created", "updated", "playbook", "play", "task")
-
-    host = NestedPlaybookHostSerializer(read_only=True)
-
-
-class NestedPlaybookTaskSerializer(serializers.ModelSerializer):
-    class Meta:
-        model = models.Task
-        exclude = ("playbook", "created", "updated")
-
-    tags = ara_fields.CompressedObjectField(read_only=True)
-    results = NestedPlaybookResultSerializer(read_only=True, many=True)
-    file = NestedPlaybookFileSerializer(read_only=True)
-
-
-class NestedPlaybookRecordSerializer(serializers.ModelSerializer):
-    class Meta:
-        model = models.Record
-        exclude = ("playbook", "value", "created", "updated")
-
-
-class NestedPlaybookPlaySerializer(serializers.ModelSerializer):
-    class Meta:
-        model = models.Play
-        exclude = ("playbook", "uuid", "created", "updated")
-
-    tasks = NestedPlaybookTaskSerializer(read_only=True, many=True)
-
-
-class NestedPlayTaskSerializer(TaskPathSerializer):
-    class Meta:
-        model = models.Task
-        exclude = ("playbook", "play", "created", "updated")
-
-    tags = ara_fields.CompressedObjectField(read_only=True)
-    results = NestedPlaybookResultSerializer(read_only=True, many=True)
-    file = NestedPlaybookFileSerializer(read_only=True)
+        exclude = ("playbook", "content", "created", "updated")
 
 
 #######
@@ -209,10 +124,6 @@ class DetailedPlaybookSerializer(ItemCountSerializer):
 
     arguments = ara_fields.CompressedObjectField(default=ara_fields.EMPTY_DICT, read_only=True)
     labels = SimpleLabelSerializer(many=True, read_only=True, default=[])
-    plays = NestedPlaybookPlaySerializer(many=True, read_only=True, default=[])
-    hosts = SimpleHostSerializer(many=True, read_only=True, default=[])
-    files = SimpleFileSerializer(many=True, read_only=True, default=[])
-    records = NestedPlaybookRecordSerializer(many=True, read_only=True, default=[])
 
 
 class DetailedPlaySerializer(ItemCountSerializer):
@@ -221,7 +132,6 @@ class DetailedPlaySerializer(ItemCountSerializer):
         fields = "__all__"
 
     playbook = SimplePlaybookSerializer(read_only=True)
-    tasks = NestedPlayTaskSerializer(many=True, read_only=True, default=[])
 
 
 class DetailedTaskSerializer(ItemCountSerializer, TaskPathSerializer):
@@ -232,7 +142,6 @@ class DetailedTaskSerializer(ItemCountSerializer, TaskPathSerializer):
     playbook = SimplePlaybookSerializer(read_only=True)
     play = SimplePlaySerializer(read_only=True)
     file = SimpleFileSerializer(read_only=True)
-    results = NestedPlaybookResultSerializer(many=True, read_only=True, default=[])
     tags = ara_fields.CompressedObjectField(read_only=True)
 
 
@@ -245,6 +154,14 @@ class DetailedHostSerializer(serializers.ModelSerializer):
     facts = ara_fields.CompressedObjectField(read_only=True)
 
 
+class DetailedLatestHostSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = models.LatestHost
+        fields = "__all__"
+
+    host = DetailedHostSerializer(read_only=True)
+
+
 class DetailedResultSerializer(ResultStatusSerializer):
     class Meta:
         model = models.Result
@@ -254,6 +171,7 @@ class DetailedResultSerializer(ResultStatusSerializer):
     play = SimplePlaySerializer(read_only=True)
     task = SimpleTaskSerializer(read_only=True)
     host = SimpleHostSerializer(read_only=True)
+    delegated_to = SimpleHostSerializer(many=True, read_only=True)
     content = ara_fields.CompressedObjectField(read_only=True)
 
 
@@ -290,7 +208,7 @@ class ListLabelSerializer(serializers.ModelSerializer):
 class ListPlaybookSerializer(ItemCountSerializer):
     class Meta:
         model = models.Playbook
-        exclude = ("created", "updated")
+        fields = "__all__"
 
     arguments = ara_fields.CompressedObjectField(default=ara_fields.EMPTY_DICT, read_only=True)
     labels = SimpleLabelSerializer(many=True, read_only=True, default=[])
@@ -299,7 +217,7 @@ class ListPlaybookSerializer(ItemCountSerializer):
 class ListPlaySerializer(ItemCountSerializer):
     class Meta:
         model = models.Play
-        exclude = ("created", "updated")
+        fields = "__all__"
 
     playbook = serializers.PrimaryKeyRelatedField(read_only=True)
 
@@ -307,7 +225,7 @@ class ListPlaySerializer(ItemCountSerializer):
 class ListTaskSerializer(ItemCountSerializer, TaskPathSerializer):
     class Meta:
         model = models.Task
-        exclude = ("created", "updated")
+        fields = "__all__"
 
     tags = ara_fields.CompressedObjectField(read_only=True)
     play = serializers.PrimaryKeyRelatedField(read_only=True)
@@ -324,18 +242,19 @@ class ListHostSerializer(serializers.ModelSerializer):
 class ListResultSerializer(ResultStatusSerializer):
     class Meta:
         model = models.Result
-        exclude = ("content", "created", "updated")
+        exclude = ("content",)
 
     playbook = serializers.PrimaryKeyRelatedField(read_only=True)
     play = serializers.PrimaryKeyRelatedField(read_only=True)
     task = serializers.PrimaryKeyRelatedField(read_only=True)
     host = serializers.PrimaryKeyRelatedField(read_only=True)
+    delegated_to = serializers.PrimaryKeyRelatedField(many=True, read_only=True)
 
 
 class ListFileSerializer(FileSha1Serializer):
     class Meta:
         model = models.File
-        exclude = ("content", "created", "updated")
+        exclude = ("content",)
 
     playbook = serializers.PrimaryKeyRelatedField(read_only=True)
 
@@ -343,7 +262,7 @@ class ListFileSerializer(FileSha1Serializer):
 class ListRecordSerializer(serializers.ModelSerializer):
     class Meta:
         model = models.Record
-        exclude = ("value", "created", "updated")
+        exclude = ("value",)
 
     playbook = serializers.PrimaryKeyRelatedField(read_only=True)
 
@@ -405,6 +324,7 @@ class HostSerializer(serializers.ModelSerializer):
         host, created = models.Host.objects.get_or_create(
             name=validated_data["name"], playbook=validated_data["playbook"], defaults=validated_data
         )
+        models.LatestHost.objects.update_or_create(name=validated_data["name"], defaults={"host": host})
         return host
 
 
@@ -414,6 +334,9 @@ class ResultSerializer(serializers.ModelSerializer):
         fields = "__all__"
 
     content = ara_fields.CompressedObjectField(default=ara_fields.EMPTY_DICT)
+    delegated_to = serializers.SlugRelatedField(
+        many=True, required=False, slug_field="id", queryset=models.Host.objects.all()
+    )
 
 
 class FileSerializer(FileSha1Serializer):
