@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import logging
 
@@ -27,6 +13,7 @@ except ImportError:
 
 from ara.api import models
 from ara.api.tests import utils
+from ara.setup import ara_version as ARA_VERSION
 
 logging.getLogger("factory").setLevel(logging.INFO)
 
@@ -43,8 +30,13 @@ class PlaybookFactory(DjangoModelFactory):
     class Meta:
         model = models.Playbook
 
+    controller = "localhost"
     name = "test-playbook"
+    user = "ara-user"
     ansible_version = "2.4.0"
+    client_version = "0.16.7"
+    server_version = ARA_VERSION
+    python_version = "3.2.1"
     status = "running"
     arguments = utils.compressed_obj(PLAYBOOK_ARGUMENTS)
     path = "/path/playbook.yml"
@@ -90,6 +82,7 @@ class TaskFactory(DjangoModelFactory):
         model = models.Task
 
     name = "test task"
+    uuid = "5c5f67b9-e63c-6297-80da-000000000006"
     status = "running"
     action = "setup"
     lineno = 2
@@ -114,6 +107,14 @@ class HostFactory(DjangoModelFactory):
     unreachable = 0
 
 
+class LatestHostFactory(DjangoModelFactory):
+    class Meta:
+        model = models.LatestHost
+
+    name = "hostname"
+    host = factory.SubFactory(HostFactory, name=name)
+
+
 class ResultFactory(DjangoModelFactory):
     class Meta:
         model = models.Result
@@ -121,6 +122,11 @@ class ResultFactory(DjangoModelFactory):
     content = utils.compressed_obj(RESULT_CONTENTS)
     status = "ok"
     host = factory.SubFactory(HostFactory)
+    # delegated_to expects a HostFactory to be assigned but it can also be []
+    # when no delegation is done.
+    # Though [] can't be declared here:
+    #     TypeError: Direct assignment to the forward side of a many-to-many set is prohibited.
+    # delegated_to = []
     task = factory.SubFactory(TaskFactory)
     play = factory.SubFactory(PlayFactory)
     playbook = factory.SubFactory(PlaybookFactory)
