@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import datetime
 
@@ -164,3 +150,22 @@ class FileTestCase(APITestCase):
         for field in order_fields:
             request = self.client.get("/api/v1/files?order=-%s" % field)
             self.assertEqual(request.data["results"][0]["id"], second_file.id)
+
+    def test_get_file_by_path(self):
+        # Create two files with similar paths
+        first_file = factories.FileFactory(path="/root/file.yaml")
+        factories.FileFactory(path="/root/some/path/file.yaml")
+
+        # Exact search should match one
+        request = self.client.get("/api/v1/files?path=/root/file.yaml")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(first_file.path, request.data["results"][0]["path"])
+
+        # Partial match should match both files
+        request = self.client.get("/api/v1/files?path=file.yaml")
+        self.assertEqual(2, len(request.data["results"]))
+
+    def test_get_playbook_arguments(self):
+        file = factories.FileFactory()
+        request = self.client.get("/api/v1/files/%s" % file.id)
+        self.assertIn("inventory", request.data["playbook"]["arguments"])
