@@ -1,22 +1,9 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import datetime
 
+from django.db.utils import IntegrityError
 from rest_framework.test import APITestCase
 
 from ara.api import models, serializers
@@ -90,8 +77,8 @@ class LabelTestCase(APITestCase):
             self.assertEqual(request.data["results"][0]["id"], label.id)
 
     def test_get_label_order(self):
-        first_label = factories.LabelFactory()
-        second_label = factories.LabelFactory()
+        first_label = factories.LabelFactory(name="first")
+        second_label = factories.LabelFactory(name="second")
 
         # Ensure we have two objects
         request = self.client.get("/api/v1/labels")
@@ -101,9 +88,16 @@ class LabelTestCase(APITestCase):
         # Ascending order
         for field in order_fields:
             request = self.client.get("/api/v1/labels?order=%s" % field)
-            self.assertEqual(request.data["results"][0]["id"], first_label.id)
+            self.assertEqual(request.data["results"][0]["name"], first_label.name)
 
         # Descending order
         for field in order_fields:
             request = self.client.get("/api/v1/labels?order=-%s" % field)
-            self.assertEqual(request.data["results"][0]["id"], second_label.id)
+            self.assertEqual(request.data["results"][0]["name"], second_label.name)
+
+    def test_unique_label_names(self):
+        # Create a first label
+        factories.LabelFactory(name="label")
+        with self.assertRaises(IntegrityError):
+            # Creating a second label with the same name should yield an exception
+            factories.LabelFactory(name="label")
