@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import datetime
 
@@ -86,6 +72,15 @@ class PlayTestCase(APITestCase):
         play_updated = models.Play.objects.get(id=play.id)
         self.assertEqual("update", play_updated.name)
 
+    def test_expired_play(self):
+        play = factories.PlayFactory(status="running")
+        self.assertEqual("running", play.status)
+
+        request = self.client.patch("/api/v1/plays/%s" % play.id, {"status": "expired"})
+        self.assertEqual(200, request.status_code)
+        play_updated = models.Play.objects.get(id=play.id)
+        self.assertEqual("expired", play_updated.status)
+
     def test_get_play(self):
         play = factories.PlayFactory()
         request = self.client.get("/api/v1/plays/%s" % play.id)
@@ -98,6 +93,17 @@ class PlayTestCase(APITestCase):
         self.assertEqual(1, len(request.data["results"]))
         self.assertEqual(play.name, request.data["results"][0]["name"])
 
+    def test_get_plays_by_name(self):
+        # Create a playbook and two plays
+        playbook = factories.PlaybookFactory()
+        play = factories.PlayFactory(name="first_play", playbook=playbook)
+        factories.PlayFactory(name="second_play", playbook=playbook)
+
+        # Query for the first play name and expect one result
+        request = self.client.get("/api/v1/plays?name=%s" % play.name)
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(play.name, request.data["results"][0]["name"])
+
     def test_get_play_by_uuid(self):
         play = factories.PlayFactory(name="play1", uuid="6b838b6f-cfc7-4e11-a264-73df8683ee0e")
         factories.PlayFactory(name="play2")
@@ -178,3 +184,8 @@ class PlayTestCase(APITestCase):
         # Test multiple status
         request = self.client.get("/api/v1/plays?status=running&status=completed")
         self.assertEqual(2, len(request.data["results"]))
+
+    def test_get_playbook_arguments(self):
+        play = factories.PlayFactory()
+        request = self.client.get("/api/v1/plays/%s" % play.id)
+        self.assertIn("inventory", request.data["playbook"]["arguments"])
