@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import datetime
 
@@ -23,6 +9,7 @@ from rest_framework.test import APITestCase
 
 from ara.api import models, serializers
 from ara.api.tests import factories, utils
+from ara.setup import ara_version as ARA_VERSION
 
 
 class PlaybookTestCase(APITestCase):
@@ -32,13 +19,24 @@ class PlaybookTestCase(APITestCase):
 
     def test_playbook_serializer(self):
         serializer = serializers.PlaybookSerializer(
-            data={"name": "serializer-playbook", "ansible_version": "2.4.0", "path": "/path/playbook.yml"}
+            data={
+                "controller": "serializer",
+                "name": "serializer-playbook",
+                "user": "ara-user",
+                "ansible_version": "2.4.0",
+                "client_version": "0.16.7",
+                "path": "/path/playbook.yml",
+            }
         )
         serializer.is_valid()
         playbook = serializer.save()
         playbook.refresh_from_db()
+        self.assertEqual(playbook.controller, "serializer")
         self.assertEqual(playbook.name, "serializer-playbook")
+        self.assertEqual(playbook.user, "ara-user")
         self.assertEqual(playbook.ansible_version, "2.4.0")
+        self.assertEqual(playbook.client_version, "0.16.7")
+        self.assertEqual(playbook.server_version, ARA_VERSION)
         self.assertEqual(playbook.status, "unknown")
 
     def test_playbook_serializer_compress_arguments(self):
@@ -93,7 +91,7 @@ class PlaybookTestCase(APITestCase):
         self.assertEqual(201, request.status_code)
         self.assertEqual(1, models.Playbook.objects.count())
         self.assertEqual(request.data["status"], "running")
-        self.assertEqual(sorted([label["name"] for label in request.data["labels"]]), sorted(labels))
+        self.assertEqual(sorted(label["name"] for label in request.data["labels"]), sorted(labels))
 
     def test_partial_update_playbook(self):
         playbook = factories.PlaybookFactory()
@@ -125,6 +123,34 @@ class PlaybookTestCase(APITestCase):
         request = self.client.get("/api/v1/playbooks/%s" % playbook.id)
         self.assertEqual(playbook.ansible_version, request.data["ansible_version"])
 
+    def test_get_playbook_by_controller(self):
+        playbook = factories.PlaybookFactory(name="playbook1", controller="controller-one")
+        factories.PlaybookFactory(name="playbook2", controller="controller-two")
+
+        # Test exact match
+        request = self.client.get("/api/v1/playbooks?controller=controller-one")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+        self.assertEqual(playbook.controller, request.data["results"][0]["controller"])
+
+        # Test partial match
+        request = self.client.get("/api/v1/playbooks?controller=controller")
+        self.assertEqual(len(request.data["results"]), 2)
+
+    def test_get_playbook_by_user(self):
+        playbook = factories.PlaybookFactory(name="playbook1", user="foobar")
+        factories.PlaybookFactory(name="playbook2", user="foobaz")
+
+        # Test exact match
+        request = self.client.get("/api/v1/playbooks?user=foobar")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+        self.assertEqual(playbook.user, request.data["results"][0]["user"])
+
+        # Test partial match
+        request = self.client.get("/api/v1/playbooks?user=foo")
+        self.assertEqual(len(request.data["results"]), 2)
+
     def test_get_playbook_by_name(self):
         playbook = factories.PlaybookFactory(name="playbook1")
         factories.PlaybookFactory(name="playbook2")
@@ -138,6 +164,62 @@ class PlaybookTestCase(APITestCase):
         request = self.client.get("/api/v1/playbooks?name=playbook")
         self.assertEqual(len(request.data["results"]), 2)
 
+    def test_get_playbook_by_ansible_version(self):
+        playbook = factories.PlaybookFactory(name="playbook1", ansible_version="2.9.1")
+        factories.PlaybookFactory(name="playbook2", ansible_version="2.8.2")
+
+        # Test exact match
+        request = self.client.get("/api/v1/playbooks?ansible_version=2.9.1")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
+        # Test partial match
+        request = self.client.get("/api/v1/playbooks?ansible_version=2.9")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
+    def test_get_playbook_by_client_version(self):
+        playbook = factories.PlaybookFactory(name="playbook1", client_version="0.16.7")
+        factories.PlaybookFactory(name="playbook2", client_version=ARA_VERSION)
+
+        # Test exact match
+        request = self.client.get("/api/v1/playbooks?client_version=0.16.7")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
+        # Test partial match
+        request = self.client.get("/api/v1/playbooks?client_version=0.16")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
+    def test_get_playbook_by_server_version(self):
+        playbook = factories.PlaybookFactory(name="playbook1", server_version="7.16.0")
+        factories.PlaybookFactory(name="playbook2", server_version=ARA_VERSION)
+
+        # Test exact match
+        request = self.client.get("/api/v1/playbooks?server_version=7.16.0")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
+        # Test partial match
+        request = self.client.get("/api/v1/playbooks?server_version=7.16")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
+    def test_get_playbook_by_python_version(self):
+        playbook = factories.PlaybookFactory(name="playbook1", python_version="3.2.1")
+        factories.PlaybookFactory(name="playbook2", python_version="4.5.6")
+
+        # Test exact match
+        request = self.client.get("/api/v1/playbooks?python_version=3.2.1")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
+        # Test partial match
+        request = self.client.get("/api/v1/playbooks?python_version=3.2")
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(playbook.name, request.data["results"][0]["name"])
+
     def test_get_playbook_by_path(self):
         playbook = factories.PlaybookFactory(path="/root/playbook.yml")
         factories.PlaybookFactory(path="/home/playbook.yml")
