@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import datetime
 
@@ -185,3 +171,8 @@ class RecordTestCase(APITestCase):
         for field in order_fields:
             request = self.client.get("/api/v1/records?order=-%s" % field)
             self.assertEqual(request.data["results"][0]["id"], second_record.id)
+
+    def test_get_playbook_arguments(self):
+        record = factories.RecordFactory()
+        request = self.client.get("/api/v1/records/%s" % record.id)
+        self.assertIn("inventory", request.data["playbook"]["arguments"])
