@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import datetime
 
@@ -30,13 +16,14 @@ class ResultTestCase(APITestCase):
         result = factories.ResultFactory(status="failed")
         self.assertEqual(result.status, "failed")
 
-    def test_result_serializer(self):
-        host = factories.HostFactory()
+    def test_result_serializer_without_delegation(self):
+        host = factories.HostFactory(name="first")
         task = factories.TaskFactory()
         serializer = serializers.ResultSerializer(
             data={
                 "status": "skipped",
                 "host": host.id,
+                "delegated_to": [],
                 "task": task.id,
                 "play": task.play.id,
                 "playbook": task.playbook.id,
@@ -51,6 +38,37 @@ class ResultTestCase(APITestCase):
         self.assertEqual(result.changed, False)
         self.assertEqual(result.ignore_errors, False)
         self.assertEqual(result.host.id, host.id)
+        # FIXME: Why does the serializer return a ManyRelatedManager queryset for delegated_to ?
+        from_queryset = list(result.delegated_to.values())
+        self.assertEqual(from_queryset, [])
+        self.assertEqual(result.task.id, task.id)
+
+    def test_result_serializer_with_delegation(self):
+        host = factories.HostFactory(name="first")
+        anotherhost = factories.HostFactory(name="second")
+        task = factories.TaskFactory()
+        serializer = serializers.ResultSerializer(
+            data={
+                "status": "skipped",
+                "host": host.id,
+                "delegated_to": [anotherhost.id],
+                "task": task.id,
+                "play": task.play.id,
+                "playbook": task.playbook.id,
+                "changed": False,
+                "ignore_errors": False,
+            }
+        )
+        serializer.is_valid()
+        result = serializer.save()
+        result.refresh_from_db()
+        self.assertEqual(result.status, "skipped")
+        self.assertEqual(result.changed, False)
+        self.assertEqual(result.ignore_errors, False)
+        self.assertEqual(result.host.id, host.id)
+        # FIXME: Why does the serializer return a ManyRelatedManager queryset for delegated_to ?
+        self.assertEqual(result.delegated_to.values()[0]["id"], anotherhost.id)
+        self.assertEqual(result.delegated_to.values()[0]["name"], anotherhost.name)
         self.assertEqual(result.task.id, task.id)
 
     def test_result_serializer_compress_content(self):
@@ -61,6 +79,7 @@ class ResultTestCase(APITestCase):
                 "content": factories.RESULT_CONTENTS,
                 "status": "ok",
                 "host": host.id,
+                "delegated_to": [],
                 "task": task.id,
                 "play": task.play.id,
                 "playbook": task.playbook.id,
@@ -103,6 +122,7 @@ class ResultTestCase(APITestCase):
                 "content": factories.RESULT_CONTENTS,
                 "status": "ok",
                 "host": host.id,
+                "delegated_to": [],
                 "task": task.id,
                 "play": task.play.id,
                 "playbook": task.playbook.id,
@@ -111,9 +131,76 @@ class ResultTestCase(APITestCase):
             },
         )
         self.assertEqual(201, request.status_code)
+        self.assertEqual(1, models.Result.objects.count())
         self.assertEqual(request.data["changed"], True)
         self.assertEqual(request.data["ignore_errors"], False)
+        self.assertEqual(request.data["status"], "ok")
+        self.assertEqual(request.data["host"], host.id)
+        self.assertEqual(request.data["delegated_to"], [])
+        self.assertEqual(request.data["task"], task.id)
+        self.assertEqual(request.data["play"], task.play.id)
+        self.assertEqual(request.data["playbook"], task.playbook.id)
+
+    def test_create_result_with_delegation(self):
+        host = factories.HostFactory(name="original")
+        delegated_host = factories.HostFactory(name="delegated")
+        task = factories.TaskFactory()
+        self.assertEqual(0, models.Result.objects.count())
+        request = self.client.post(
+            "/api/v1/results",
+            {
+                "content": factories.RESULT_CONTENTS,
+                "status": "ok",
+                "host": host.id,
+                "delegated_to": [delegated_host.id],
+                "task": task.id,
+                "play": task.play.id,
+                "playbook": task.playbook.id,
+                "changed": True,
+                "ignore_errors": False,
+            },
+        )
+        self.assertEqual(201, request.status_code)
         self.assertEqual(1, models.Result.objects.count())
+        self.assertEqual(request.data["changed"], True)
+        self.assertEqual(request.data["ignore_errors"], False)
+        self.assertEqual(request.data["status"], "ok")
+        self.assertEqual(request.data["host"], host.id)
+        self.assertEqual(request.data["delegated_to"], [delegated_host.id])
+        self.assertEqual(request.data["task"], task.id)
+        self.assertEqual(request.data["play"], task.play.id)
+        self.assertEqual(request.data["playbook"], task.playbook.id)
+
+    def test_create_result_with_two_delegations(self):
+        host = factories.HostFactory(name="original")
+        delegated_host = factories.HostFactory(name="delegated")
+        another_host = factories.HostFactory(name="another")
+        task = factories.TaskFactory()
+        self.assertEqual(0, models.Result.objects.count())
+        request = self.client.post(
+            "/api/v1/results",
+            {
+                "content": factories.RESULT_CONTENTS,
+                "status": "ok",
+                "host": host.id,
+                "delegated_to": [delegated_host.id, another_host.id],
+                "task": task.id,
+                "play": task.play.id,
+                "playbook": task.playbook.id,
+                "changed": True,
+                "ignore_errors": False,
+            },
+        )
+        self.assertEqual(201, request.status_code)
+        self.assertEqual(1, models.Result.objects.count())
+        self.assertEqual(request.data["changed"], True)
+        self.assertEqual(request.data["ignore_errors"], False)
+        self.assertEqual(request.data["status"], "ok")
+        self.assertEqual(request.data["host"], host.id)
+        self.assertEqual(request.data["delegated_to"], [delegated_host.id, another_host.id])
+        self.assertEqual(request.data["task"], task.id)
+        self.assertEqual(request.data["play"], task.play.id)
+        self.assertEqual(request.data["playbook"], task.playbook.id)
 
     def test_partial_update_result(self):
         result = factories.ResultFactory()
@@ -284,3 +371,8 @@ class ResultTestCase(APITestCase):
         results = self.client.get("/api/v1/results?changed=false").data["results"]
         self.assertEqual(1, len(results))
         self.assertEqual(results[0]["id"], unchanged_result.id)
+
+    def test_get_playbook_arguments(self):
+        result = factories.ResultFactory()
+        request = self.client.get("/api/v1/results/%s" % result.id)
+        self.assertIn("inventory", request.data["playbook"]["arguments"])
