@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import datetime
 
@@ -36,6 +22,7 @@ class TaskTestCase(APITestCase):
         serializer = serializers.TaskSerializer(
             data={
                 "name": "serializer",
+                "uuid": "5c5f67b9-e63c-6297-80da-000000000009",
                 "action": "test",
                 "lineno": 2,
                 "status": "completed",
@@ -49,6 +36,7 @@ class TaskTestCase(APITestCase):
         task = serializer.save()
         task.refresh_from_db()
         self.assertEqual(task.name, "serializer")
+        self.assertEqual(str(task.uuid), "5c5f67b9-e63c-6297-80da-000000000009")
         self.assertEqual(task.status, "completed")
 
     def test_task_serializer_compress_tags(self):
@@ -57,6 +45,7 @@ class TaskTestCase(APITestCase):
         serializer = serializers.TaskSerializer(
             data={
                 "name": "compress",
+                "uuid": "5c5f67b9-e63c-6297-80da-000000000009",
                 "action": "test",
                 "lineno": 2,
                 "status": "running",
@@ -102,6 +91,7 @@ class TaskTestCase(APITestCase):
             "/api/v1/tasks",
             {
                 "name": "create",
+                "uuid": "5c5f67b9-e63c-6297-80da-000000000009",
                 "action": "test",
                 "lineno": 2,
                 "handler": False,
@@ -145,6 +135,26 @@ class TaskTestCase(APITestCase):
         self.assertEqual(task.name, request.data["results"][1]["name"])
         self.assertEqual("task2", request.data["results"][0]["name"])
 
+    def test_get_tasks_by_play(self):
+        playbook = factories.PlaybookFactory()
+        # Create two plays
+        play = factories.PlayFactory(name="first_play", playbook=playbook)
+        second_play = factories.PlayFactory(name="second_play", playbook=playbook)
+        request = self.client.get("/api/v1/plays")
+        self.assertEqual(2, len(request.data["results"]))
+
+        # Add tasks for the first play and validate
+        task = factories.TaskFactory(name="inside_first", play=play)
+        factories.TaskFactory(name="inside_second", play=play)
+
+        request = self.client.get("/api/v1/tasks?play=%s" % play.id)
+        self.assertEqual(2, len(request.data["results"]))
+        self.assertEqual(task.name, request.data["results"][1]["name"])
+        self.assertEqual("inside_second", request.data["results"][0]["name"])
+
+        request = self.client.get("/api/v1/tasks?play=%s" % second_play.id)
+        self.assertEqual(0, len(request.data["results"]))
+
     def test_get_tasks_by_name(self):
         # Create a playbook and two tasks
         playbook = factories.PlaybookFactory()
@@ -156,6 +166,18 @@ class TaskTestCase(APITestCase):
         self.assertEqual(1, len(request.data["results"]))
         self.assertEqual(task.name, request.data["results"][0]["name"])
 
+    def test_get_tasks_by_uuid(self):
+        # Create a playbook and two tasks
+        playbook = factories.PlaybookFactory()
+        task = factories.TaskFactory(uuid="5c5f67b9-e63c-6297-80da-000000000009", playbook=playbook)
+        # Default gets a different uuid
+        factories.TaskFactory(playbook=playbook)
+
+        # Query for the first task uuid and expect one result
+        request = self.client.get("/api/v1/tasks?uuid=%s" % task.uuid)
+        self.assertEqual(1, len(request.data["results"]))
+        self.assertEqual(task.uuid, request.data["results"][0]["uuid"])
+
     def test_get_task_duration(self):
         started = timezone.now()
         ended = started + datetime.timedelta(hours=1)
@@ -216,10 +238,11 @@ class TaskTestCase(APITestCase):
         task = factories.TaskFactory(status="running")
         factories.TaskFactory(status="completed")
         factories.TaskFactory(status="unknown")
+        factories.TaskFactory(status="failed")
 
-        # Confirm we have three objects
+        # Confirm we have four tasks
         request = self.client.get("/api/v1/tasks")
-        self.assertEqual(3, len(request.data["results"]))
+        self.assertEqual(4, len(request.data["results"]))
 
         # Test single status
         request = self.client.get("/api/v1/tasks?status=running")
@@ -261,3 +284,8 @@ class TaskTestCase(APITestCase):
         # Test partial match
         request = self.client.get("/api/v1/tasks?path=main.yml")
         self.assertEqual(len(request.data["results"]), 2)
+
+    def test_get_playbook_arguments(self):
+        task = factories.TaskFactory()
+        request = self.client.get("/api/v1/tasks/%s" % task.id)
+        self.assertIn("inventory", request.data["playbook"]["arguments"])
