@@ -1,19 +1,5 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from rest_framework import viewsets
 
@@ -40,8 +26,8 @@ class PlaybookViewSet(viewsets.ModelViewSet):
     def get_queryset(self):
         statuses = self.request.GET.getlist("status")
         if statuses:
-            return models.Playbook.objects.filter(status__in=statuses)
-        return models.Playbook.objects.all()
+            return models.Playbook.objects.filter(status__in=statuses).order_by("-id")
+        return models.Playbook.objects.all().order_by("-id")
 
     def get_serializer_class(self):
         if self.action == "list":
@@ -52,6 +38,27 @@ class PlaybookViewSet(viewsets.ModelViewSet):
             # create/update/destroy
             return serializers.PlaybookSerializer
 
+    def perform_destroy(self, instance):
+        """
+        Update the LatestHost table when deleting a playbook (if necessary)
+        """
+        # check if Host object has a relation to a LatestHost object
+        for host in instance.hosts.all():
+            try:
+                latest = models.LatestHost.objects.get(host=host.id)
+            except models.LatestHost.DoesNotExist:
+                # No need to delete the host, the cascade will take care of it
+                continue
+
+            # Find the next-latest host that isn't this one
+            next_latest = models.Host.objects.filter(name=host.name).order_by("-updated")
+
+            if len(next_latest) > 1:
+                latest.host = next_latest[1]
+                latest.save()
+
+        return super().perform_destroy(instance)
+
 
 class PlayViewSet(viewsets.ModelViewSet):
     filterset_class = filters.PlayFilter
@@ -59,8 +66,8 @@ class PlayViewSet(viewsets.ModelViewSet):
     def get_queryset(self):
         statuses = self.request.GET.getlist("status")
         if statuses:
-            return models.Play.objects.filter(status__in=statuses)
-        return models.Play.objects.all()
+            return models.Play.objects.filter(status__in=statuses).order_by("-id")
+        return models.Play.objects.all().order_by("-id")
 
     def get_serializer_class(self):
         if self.action == "list":
@@ -78,8 +85,8 @@ class TaskViewSet(viewsets.ModelViewSet):
     def get_queryset(self):
         statuses = self.request.GET.getlist("status")
         if statuses:
-            return models.Task.objects.filter(status__in=statuses)
-        return models.Task.objects.all()
+            return models.Task.objects.filter(status__in=statuses).order_by("-id")
+        return models.Task.objects.all().order_by("-id")
 
     def get_serializer_class(self):
         if self.action == "list":
@@ -95,6 +102,25 @@ class HostViewSet(viewsets.ModelViewSet):
     queryset = models.Host.objects.all()
     filterset_class = filters.HostFilter
 
+    def perform_destroy(self, instance):
+        """
+        Update the LatestHost table when deleting a host (if necessary)
+        """
+        # check if Host object has a relation to a LatestHost object
+        try:
+            latest = models.LatestHost.objects.get(host=instance.id)
+        except models.LatestHost.DoesNotExist:
+            return super().perform_destroy(instance)
+
+        # Find the next-latest host that isn't this one
+        next_latest = models.Host.objects.filter(name=instance.name).order_by("-updated")
+
+        if len(next_latest) > 1:
+            latest.host = next_latest[1]
+            latest.save()
+
+        return super().perform_destroy(instance)
+
     def get_serializer_class(self):
         if self.action == "list":
             return serializers.ListHostSerializer
@@ -105,14 +131,20 @@ class HostViewSet(viewsets.ModelViewSet):
             return serializers.HostSerializer
 
 
+class LatestHostViewSet(viewsets.ReadOnlyModelViewSet):
+    queryset = models.LatestHost.objects.all()
+    filterset_class = filters.LatestHostFilter
+    serializer_class = serializers.DetailedLatestHostSerializer
+
+
 class ResultViewSet(viewsets.ModelViewSet):
     filterset_class = filters.ResultFilter
 
     def get_queryset(self):
         statuses = self.request.GET.getlist("status")
         if statuses:
-            return models.Result.objects.filter(status__in=statuses)
-        return models.Result.objects.all()
+            return models.Result.objects.filter(status__in=statuses).order_by("-id")
+        return models.Result.objects.all().order_by("-id")
 
     def get_serializer_class(self):
         if self.action == "list":
