@@ -1,8 +1,9 @@
-# Copyright (c) 2020 The ARA Records Ansible authors
+# Copyright (c) 2022 The ARA Records Ansible authors
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import functools
 import os
+from datetime import datetime, timedelta
 
 
 @functools.lru_cache(maxsize=10)
@@ -29,6 +30,32 @@ def get_host(client, host_id):
     return host
 
 
+def parse_timedelta(duration: str, pattern: str = "%H:%M:%S.%f"):
+    """Parses a timedelta string back into a timedelta object"""
+    parsed = datetime.strptime(duration, pattern)
+    # fmt: off
+    return timedelta(
+        hours=parsed.hour,
+        minutes=parsed.minute,
+        seconds=parsed.second,
+        microseconds=parsed.microsecond
+    ).total_seconds()
+    # fmt: on
+
+
+def sum_timedelta(duration: str, total: float):
+    """
+    Returns the sum of two timedeltas as provided by the API, for example:
+    00:00:02.031557 + 00:00:04.782581 = ?
+    """
+    return parse_timedelta(duration) + total
+
+
+def avg_timedelta(delta: timedelta, count: int):
+    """Returns an average timedelta based on the amount of occurrences"""
+    return str(delta / count)
+
+
 # Also see: ui.templatetags.truncatepath
 def truncatepath(path, count):
     """
