@@ -1,50 +1,40 @@
-#  Copyright (c) 2018 Red Hat, Inc.
-#
-#  This file is part of ARA: Ansible Run Analysis.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
-
-# This is an "offline" API client that does not require standing up
-# an API server and does not execute actual HTTP calls.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import json
 import logging
 import weakref
 
-import pbr.version
 import requests
+import urllib3
 
 from ara.clients.utils import active_client
-
-CLIENT_VERSION = pbr.version.VersionInfo("ara").release_string()
+from ara.setup import ara_version
 
 
-class HttpClient(object):
-    def __init__(self, endpoint="http://127.0.0.1:8000", timeout=30, auth=None):
+class HttpClient:
+    def __init__(self, endpoint="http://127.0.0.1:8000", auth=None, cert=None, timeout=30, verify=True):
         self.log = logging.getLogger(__name__)
 
-        self.endpoint = endpoint
-        self.timeout = timeout
+        self.endpoint = endpoint.rstrip("/")
+        self.auth = auth
+        self.cert = cert
+        self.timeout = int(timeout)
+        self.verify = verify
         self.headers = {
-            "User-Agent": "ara-http-client_%s" % CLIENT_VERSION,
+            "User-Agent": "ara-http-client_%s" % ara_version,
             "Accept": "application/json",
             "Content-Type": "application/json",
         }
         self.http = requests.Session()
         self.http.headers.update(self.headers)
-        if auth is not None:
-            self.http.auth = auth
+        if self.auth is not None:
+            self.http.auth = self.auth
+        if self.cert is not None:
+            self.http.cert = self.cert
+        if not self.verify:
+            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+        self.http.verify = self.verify
 
     def _request(self, method, url, **payload):
         # Use requests.Session to do the query
@@ -72,10 +62,17 @@ class HttpClient(object):
         return self._request("delete", url)
 
 
-class AraHttpClient(object):
-    def __init__(self, endpoint="http://127.0.0.1:8000", timeout=30, auth=None):
+class AraHttpClient:
+    def __init__(self, endpoint="http://127.0.0.1:8000", auth=None, cert=None, timeout=30, verify=True):
         self.log = logging.getLogger(__name__)
-        self.client = HttpClient(endpoint, timeout, auth=auth)
+        self.endpoint = endpoint
+        self.auth = auth
+        self.cert = cert
+        self.timeout = int(timeout)
+        self.verify = verify
+        self.client = HttpClient(
+            endpoint=self.endpoint, timeout=self.timeout, auth=self.auth, cert=self.cert, verify=self.verify
+        )
         active_client._instance = weakref.ref(self)
 
     def _request(self, method, url, **kwargs):
@@ -86,12 +83,12 @@ class AraHttpClient(object):
             response = func(url, **kwargs)
 
         if response.status_code >= 500:
-            self.log.error("Failed to {method} on {url}: {content}".format(method=method, url=url, content=kwargs))
+            self.log.error(f"Failed to {method} on {url}: {kwargs}")
 
-        self.log.debug("HTTP {status}: {method} on {url}".format(status=response.status_code, method=method, url=url))
+        self.log.debug(f"HTTP {response.status_code}: {method} on {url}")
 
         if response.status_code not in [200, 201, 204]:
-            self.log.error("Failed to {method} on {url}: {content}".format(method=method, url=url, content=kwargs))
+            self.log.error(f"Failed to {method} on {url}: {kwargs}")
 
         if response.status_code == 204:
             return response
