@@ -1,27 +1,18 @@
-#!/usr/bin/env python
-#  Copyright (c) 2019 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+#!/usr/bin/env python3
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import os
 import sys
 
 from django.conf import settings
 
-from ara.setup.exceptions import MissingDjangoException, MissingMysqlclientException, MissingPsycopgException
+from ara.setup.exceptions import (
+    MissingDjangoException,
+    MissingMysqlclientException,
+    MissingPsycopgException,
+    MissingSettingsException,
+)
 
 
 def main():
@@ -32,6 +23,12 @@ def main():
     except ImportError as e:
         raise MissingDjangoException from e
 
+    # Validate that the settings file exists and is readable before bootstrapping
+    if not os.path.exists(settings.ARA_SETTINGS):
+        print("[ara] Unable to access or read settings file: %s" % settings.ARA_SETTINGS)
+        raise MissingSettingsException
+    print("[ara] Using settings file: %s" % settings.ARA_SETTINGS)
+
     if settings.DATABASE_ENGINE == "django.db.backends.postgresql":
         try:
             import psycopg2  # noqa
@@ -45,7 +42,6 @@ def main():
             raise MissingMysqlclientException from e
 
     execute_from_command_line(sys.argv)
-    print("[ara] Using settings file: %s" % settings.ARA_SETTINGS)
 
 
 if __name__ == "__main__":
