@@ -1,19 +1,5 @@
-#  Copyright (c) 2019 Red Hat, Inc.
-#
-#  This file is part of ARA Records Ansible.
-#
-#  ARA is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  ARA is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2022 The ARA Records Ansible authors
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 import os
 import textwrap
@@ -35,52 +21,57 @@ DEFAULT_SETTINGS = os.path.join(BASE_DIR, "settings.yaml")
 
 settings = LazySettings(
     environments=True,
-    GLOBAL_ENV_FOR_DYNACONF="ARA",
+    ENVVAR_PREFIX_FOR_DYNACONF="ARA",
     ENVVAR_FOR_DYNACONF="ARA_SETTINGS",
-    SETTINGS_MODULE_FOR_DYNACONF=DEFAULT_SETTINGS,
+    SETTINGS_FILE_FOR_DYNACONF=DEFAULT_SETTINGS,
 )
 
 # reread BASE_DIR since it might have gotten changed in the config file.
 BASE_DIR = settings.get("BASE_DIR", BASE_DIR)
 
+# Deploy ARA on a subpath, useful when behind a reverse proxy
+# NOTE: This also modifies stuff like STATIC_URL
+BASE_PATH = settings.get("BASE_PATH", "/")
+
 # Django doesn't set up logging until it's too late to use it in settings.py.
 # Set it up from the configuration so we can use it.
 DEBUG = settings.get("DEBUG", False, "@bool")
 
 LOG_LEVEL = settings.get("LOG_LEVEL", "INFO")
-# fmt: off
-LOGGING = {
-    "version": 1,
-    "disable_existing_loggers": False,
-    "formatters": {"normal": {"format": "%(asctime)s %(levelname)s %(name)s: %(message)s"}},
-    "handlers": {
-        "console": {
-            "class": "logging.StreamHandler",
-            "formatter": "normal",
-            "level": LOG_LEVEL,
-            "stream": "ext://sys.stdout",
-        }
+# default logger updated cf issue https://github.com/ansible-community/ara/issues/228
+# and PR https://github.com/ansible-community/ara/pull/367
+LOGGING = settings.get(
+    "LOGGING",
+    {
+        "version": 1,
+        "disable_existing_loggers": False,
+        "formatters": {"normal": {"format": "%(asctime)s %(levelname)s %(name)s: %(message)s"}},
+        "handlers": {
+            "console": {
+                "class": "logging.StreamHandler",
+                "formatter": "normal",
+                "level": LOG_LEVEL,
+                "stream": "ext://sys.stdout",
+            }
+        },
+        "loggers": {"ara": {"handlers": ["console"], "level": LOG_LEVEL, "propagate": 0}},
     },
-    "loggers": {
-        "ara": {
-            "handlers": ["console"],
-            "level": LOG_LEVEL,
-            "propagate": 0
-        }
-    },
-    "root": {
-        "handlers": ["console"],
-        "level": LOG_LEVEL
-    },
-}
-# fmt: on
+).to_dict()
 
+if "root" in LOGGING:
+    print(
+        "[ara] Server's LOGGING configuration has a 'root' logger which is deprecated after version 1.5.8 "
+        "due to conflicts. Please update your settings.yaml or generate a new one by "
+        "removing it from ara's configuration folder"
+    )
+    del LOGGING["root"]
 
 # Django built-in server and npm development server
 ALLOWED_HOSTS = settings.get("ALLOWED_HOSTS", ["::1", "127.0.0.1", "localhost"])
 CORS_ORIGIN_WHITELIST = settings.get("CORS_ORIGIN_WHITELIST", ["http://127.0.0.1:8000", "http://localhost:3000"])
 CORS_ORIGIN_REGEX_WHITELIST = settings.get("CORS_ORIGIN_REGEX_WHITELIST", [])
 CORS_ORIGIN_ALLOW_ALL = settings.get("CORS_ORIGIN_ALLOW_ALL", False)
+CSRF_TRUSTED_ORIGINS = settings.get("CSRF_TRUSTED_ORIGINS", [])
 
 ADMINS = settings.get("ADMINS", ())
 
@@ -110,12 +101,7 @@ DISTRIBUTED_SQLITE_PREFIX = settings.get("DISTRIBUTED_SQLITE_PREFIX", "ara-repor
 # "/var/www/logs/some/path/ara-report" instead of "/some/path/ara-report".
 DISTRIBUTED_SQLITE_ROOT = settings.get("DISTRIBUTED_SQLITE_ROOT", "/var/www/logs")
 
-if DISTRIBUTED_SQLITE:
-    WSGI_APPLICATION = "ara.server.wsgi.distributed_sqlite"
-    DATABASE_ENGINE = settings.get("DATABASE_ENGINE", "ara.server.db.backends.distributed_sqlite")
-else:
-    WSGI_APPLICATION = "ara.server.wsgi.application"
-    DATABASE_ENGINE = settings.get("DATABASE_ENGINE", "django.db.backends.sqlite3")
+WSGI_APPLICATION = "ara.server.wsgi.application"
 
 # We're not expecting ARA to use multiple concurrent databases.
 # Make it easier for users to specify the configuration for a single database.
@@ -130,7 +116,7 @@ DATABASE_OPTIONS = settings.get("DATABASE_OPTIONS", {})
 
 DATABASES = {
     "default": {
-        "ENGINE": DATABASE_ENGINE,
+        "ENGINE": "ara.server.db.backends.distributed_sqlite" if DISTRIBUTED_SQLITE else DATABASE_ENGINE,
         "NAME": DATABASE_NAME,
         "USER": DATABASE_USER,
         "PASSWORD": DATABASE_PASSWORD,
@@ -155,6 +141,13 @@ INSTALLED_APPS = [
     "ara.api",
     "ara.ui",
     "ara.server.apps.AraAdminConfig",
+    # NOTE: django_extensions is not currently meant to be enabled except for the single purpose of generating
+    #       a database graph for the documentation.
+    # See:
+    # - doc/source/_graphs/database_graph_model.sh
+    # - https://django-extensions.readthedocs.io/en/latest/installation_instructions.html
+    # - https://django-extensions.readthedocs.io/en/latest/graph_models.html
+    # "django_extensions",
 ]
 
 EXTERNAL_AUTH_MIDDLEWARE = []
@@ -191,6 +184,7 @@ TEMPLATES = [
                 "django.template.context_processors.request",
                 "django.contrib.auth.context_processors.auth",
                 "django.contrib.messages.context_processors.messages",
+                "ara.server.context_processors.about",
             ]
         },
     }
@@ -204,7 +198,12 @@ AUTH_PASSWORD_VALIDATORS = [
 ]
 
 USE_TZ = True
-LOCAL_TIME_ZONE = tzlocal.get_localzone().zone
+# Under some circumstances tzlocal can't find the local timezone, it will return local or None
+# Default to UTC if this happens.
+# https://github.com/ansible-community/ara/issues/401
+LOCAL_TIME_ZONE = tzlocal.get_localzone_name()
+if LOCAL_TIME_ZONE is None or LOCAL_TIME_ZONE == "local":
+    LOCAL_TIME_ZONE = "UTC"
 TIME_ZONE = settings.get("TIME_ZONE", LOCAL_TIME_ZONE)
 
 # We do not currently support internationalization and localization, turn these
@@ -220,7 +219,6 @@ warnings.filterwarnings("ignore", message="No directory at", module="whitenoise.
 
 STATIC_URL = settings.get("STATIC_URL", "/static/")
 STATIC_ROOT = settings.get("STATIC_ROOT", os.path.join(BASE_DIR, "www", "static"))
-
 MEDIA_URL = settings.get("MEDIA_URL", "/media/")
 MEDIA_ROOT = settings.get("MEDIA_ROOT", os.path.join(BASE_DIR, "www", "media"))
 
@@ -235,7 +233,7 @@ REST_FRAMEWORK = {
     "DEFAULT_FILTER_BACKENDS": ("django_filters.rest_framework.DjangoFilterBackend",),
     "DEFAULT_RENDERER_CLASSES": (
         "rest_framework.renderers.JSONRenderer",
-        "rest_framework.renderers.BrowsableAPIRenderer",
+        "ara.api.renderers.BrowsableAPIRendererWithoutForms",
     ),
     "DEFAULT_PARSER_CLASSES": (
         "rest_framework.parsers.JSONParser",
@@ -260,10 +258,12 @@ if not os.path.isdir(BASE_DIR):
 if not os.path.exists(DEFAULT_SETTINGS) and "ARA_SETTINGS" not in os.environ:
     SETTINGS = dict(
         BASE_DIR=BASE_DIR,
+        BASE_PATH=BASE_PATH,
         ALLOWED_HOSTS=ALLOWED_HOSTS.to_list(),
         CORS_ORIGIN_WHITELIST=CORS_ORIGIN_WHITELIST.to_list(),
         CORS_ORIGIN_REGEX_WHITELIST=CORS_ORIGIN_REGEX_WHITELIST.to_list(),
         CORS_ORIGIN_ALLOW_ALL=CORS_ORIGIN_ALLOW_ALL,
+        CSRF_TRUSTED_ORIGINS=CSRF_TRUSTED_ORIGINS.to_list(),
         EXTERNAL_AUTH=EXTERNAL_AUTH,
         SECRET_KEY=SECRET_KEY,
         DATABASE_ENGINE=DATABASE_ENGINE,
@@ -301,3 +301,8 @@ if not os.path.exists(DEFAULT_SETTINGS) and "ARA_SETTINGS" not in os.environ:
         print("[ara] Writing default settings to %s" % DEFAULT_SETTINGS)
         settings_file.write(comment.lstrip())
         yaml.dump({"default": SETTINGS}, settings_file, default_flow_style=False)
+
+if BASE_PATH:
+    BASE_PATH = BASE_PATH.rstrip("/")
+    if STATIC_URL.startswith("/") and not STATIC_URL.startswith("//"):
+        STATIC_URL = BASE_PATH + STATIC_URL
